### This project contains input files for DPA evaluations using FLUKA,
PHITS and MCNP6

## PHITS:

__```phits/mu2e_DPA.i```__

Input file for PHITS which models the MU2E-tungsten target (simulation is
done with 800 MeV proton beam, so MU2E-II conditions). Transport and
Productions thresholds are close to what is used in the FLUKA input.

Execute with

```phits.sh mu2e_DPA.i```

(it works only with version 3.26, earlier versions do not have the ```arc-dpa``` tallying).

### Output files:

```nrt-dpa.out``` contains the information for the ```nrt-dpa``` tallying (with ```idpa = 0``` in the input file),
while ```arc-dpa.out``` contains information for ```arc-dpa```
(```idpa = 1``` in the input file)

Units are ```DPA/source proton```. Typical values in this case are ```7.5E-21``` DPA/source or ```1.5E-21``` DPA/source.

## FLUKA:

__```fluka/mu2e_DPA.inp```__

Input file for FLUKA which models the MU2E-tungsten target (simulation is
done with 800 MeV proton beam, so MU2EU-II conditions).

Execute with

```
$FLUPRO/flutil/ldpmqmd -o FLUKA_DPA.exe

$FLUPRO/flutil/rfluka  -e  ./FLUKA_DPA.exe  -N0 -M5  ./mu2e_DPA
```

(it works only with version 2021.2.3 and higher, earlier versions do not have
the ```DPA-NRT``` scoring).

### Output files
```mu2e_DPA*_fort.44```
Cylindrical USRBIN-scorer with 1 bin containing the tungsten rod. Process,
and then pass the resulting `.bnn`-file to `$FLUPRO/flutil/usbrea` to acess the bin content in `ASCII`.

DPA is evaluated in three ways:

```RNiel1RZ```: ```RES-NIEL```-scoring. This gives the result in GeV/cm3 of
Restricted energy deposition above damage threshold NIEL. This can be converted to a rough DPA-estimate using the formula

$$
0.8 \times RES-NIEL /(2\times E_{thr}) \times 1E9 \times amu_{W} / \rho_{W} / 6.02E23
$$

where $ \rho_{W} $ is the density of tungsten (19.3g/cm3), $ amu_{W} $ is the atomic weight (183.84), 6.02E23 is the Avogadro-number and RES-NIEL is the scoring output

This is an example calculation in ```ROOT```:

```
root [0] 0.8*1.0794E-04/(2.*90.)*1.E9*183.84/19.3/6.02E23

(double) 7.5907748e-21
```

```Dpa1RZ```: ```DPA-SCO```-scoring. This gives directly the result in DPA, and is a more sophisticated method than the crude estimate above (which does not include athermal recombination).

```NRT1RZ```: ```DPA-NRT```-scoring. This implements directly (since FLUKA2021.2.3) the above mentioned formula based on the RES-NIEL scoring.


```mu2e_DPA*_fort.46```

Contains the same information as above, but in a REGION-binning, so the
results need to be divided by the volume of the tungsten rod (4.9875925cm3).

```NielReg```

```DpaReg```

```NRTReg```

# MCNP6

```mu2e_DPA.i```

Input file for MCNP6 which models the MU2E-tungsten target (simulation is
done with 800 MeV proton beam, so MU2E-II conditions). This needs the
displacement cross section files from Konobeyev et al.,
Nucl. Eng. and Techn. 51 (2019) 170-175 (see
https://www-nds.iaea.org/public/download-endf/DXS/Displacement_XS/DXS.(2018)/)

Run it with (```$DATAPATH/xsdir_mcnp6.2_endf80``` should include the
displacement cross section for tungsten) 

```mcnp6 i=mu2e_DPA.i o=mu2e_DPA.o xsdir=$DATAPATH/xsdir_mcnp6.2_endf80```

Neutron induced microscopic displacement reaction rate (RR) in tally 134 (NRT) and tally 144 (arc).

Proton induced microscopic displacement reaction rate (RR) in tally 224 (NRT) and tally 234 (arc).

RR values need to be multiplied by

$$
RR \times N \times V / A
$$

where N is the atomic density of tungsten (6.32E-02 atoms/cm-barn),  V is the target volume (4.99cm3) and A is the total number of atoms in the target volume (3.15E23 atoms).

Typical values are 8.5E-21 for NRT and 2.11E-21 for arc-dpa.
